@@ -22,7 +22,8 @@ class BitmexClient:
 
     def get_wallet(self, prop):
         try:
-            wallet_balance = self.client.User.User_getWallet().result()[0][str(prop)]
+            wallet_balance = self.client.User.User_getWallet().result()[
+                0][str(prop)]
             self._last_wallet_balance = wallet_balance
             return wallet_balance
         except HTTPBadRequest:
@@ -79,7 +80,7 @@ class BitmexClient:
                 # print('API error getting current price', e, flush=True)
                 pass
             return self.last_current_price(symbol)
-        
+
     def last_current_price(self, symbol):
         if symbol in self._last_currentprice.keys():
             return self._last_currentprice[symbol]
@@ -238,7 +239,8 @@ class BitmexOrder:
         try:
             self.props[symbol]['stoploss_id'] = self.generate_id(
                 symbol, _type='SL')
-            self.save_open_id(symbol, self.props[symbol]['stoploss_id'], stop_type='stoploss')
+            self.save_open_id(
+                symbol, self.props[symbol]['stoploss_id'], stop_type='stoploss')
             return self.client.client.Order.Order_new(
                 symbol=symbol, ordType='Stop', clOrdID=self.props[symbol]['stoploss_id'], orderQty=-self.props[symbol]['qty'],
                 stopPx=self.price_decimals(symbol, self.props[symbol]['SL']), execInst=execPrice
@@ -311,7 +313,7 @@ class BitmexOrder:
             # could be clOrdID, not sure difference
             res = self.client.client.Order.Order_amend(
                 origClOrdID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
-                                                                                        newPrice)
+                                                                                          newPrice)
             ).result()
             return res
         except HTTPBadRequest as e:
@@ -326,10 +328,13 @@ class BitmexOrder:
         if not qty:
             qty = -self.props[symbol]['qty']
         if self.props[symbol]['open']:
+            # note: have to delete stop too
             try:
-                return self.client.client.Order.Order_new(
+                close = self.client.client.Order.Order_new(
                     symbol=symbol, ordType='Market', execInst='Close', orderQty=qty
                 ).result()
+                self.stoploss_cancel(symbol)
+                return close
             except HTTPBadRequest as e:
                 print("Error closing order in {}.".format(symbol), e, flush=True)
         else:
