@@ -6,7 +6,8 @@ from dateutil import parser
 from algo_trader.clients import BitmexOrder
 import requests
 import os
-
+import signal
+import sys
 
 class Lotus:
     def __init__(self, client, symbols, settings, setting_file_name):
@@ -28,6 +29,8 @@ class Lotus:
         self._last_entry = {}
         self._last_sl = {}
 
+        signal.signal(signal.SIGINT, self.signal_handler)
+
         for symbol in symbols:
             self._last_timestamp[symbol] = datetime.datetime.utcnow()
             self._last_entry[symbol] = ''
@@ -39,9 +42,16 @@ class Lotus:
             sys.exit()
 
     # helper function
-    def ceil_dt(dt, delta):
+    def ceil_dt(self, dt, delta):
         return dt + (datetime.datetime.min - dt) % delta
 
+    def signal_handler(self, signal, frame):
+        print('Doing things before exit...')
+        for symbol in self.symbols:
+            if self.order.props[symbol]['wait_stop']:
+                self.order.close(symbol)  # cancel old order first
+        sys.exit(0)
+
     def is_new_signal_symbol(self, signal, symbol):
         timestamp = parser.parse(signal[symbol]['timestamp'])
         if self._last_timestamp[symbol] != timestamp:
@@ -57,10 +67,10 @@ class Lotus:
             return requests.get(self._api_endpoint, params=auth).json()
         except ValueError:
             print("Can't get signal on endpoint {} with token {}. Please make sure your token is the right one and endpoint is set correct."
-                  "It could also be that you are timed out because you try to access with multiple IP's. In this case wait 40 minutes to be able to access again.".format(
+                  " It could also be that you are timed out because you try to access with multiple IP's. In this case wait 40 minutes to be able to access again.".format(
                       self._api_endpoint, self.settings.token))
             return False
-    
+
     def is_new_signal(self, signal):
         # tests if signal has new timestamp
         if signal['timestamp'] != self._last_signal_timestamp:
@@ -87,14 +97,15 @@ class Lotus:
             time.sleep(3)
         elif self.order.props[symbol]['open']:
             print("Close old order {} first, because of new signal".format(symbol))
-            self.order.close(symbol)  # cancel old order first
+            self.order.close(symbol, self.client.open_contracts(symbol))  # cancel old order first
             time.sleep(3)
 
     def process_signals(self, ns, start=False):
         for symbol in self.symbols:
             if start:
                 if ns[symbol]['signal']:
-                    self.order.check_open_bot_order(symbol, ns[symbol]['entry'], ns[symbol]['stoploss'])
+                    self.order.check_open_bot_order(
+                        symbol, ns[symbol]['entry'], ns[symbol]['stoploss'])
                     time.sleep(3)
             signal = ns[symbol]['signal']
             if signal:
@@ -158,7 +169,8 @@ class Lotus:
                                             symbol, -contracts, stoploss, cp)
                     elif signal in [-2, 2]:  # signal has pending order
                         self.manage_open_stop_orders(symbol)
-                        contracts = self.order.calc_pos_size(symbol, abs(entry - stoploss))
+                        contracts = self.order.calc_pos_size(
+                            symbol, abs(entry - stoploss))
                         if signal == 2:
                             print("Open bracket stop order long. {} {} Contracts, Entry: {}, Stoploss: {}".format(
                                 symbol, contracts, entry, stoploss), flush=True)
@@ -175,12 +187,13 @@ class Lotus:
             else:
                 self.manage_open_stop_orders(symbol)
                 print("This position update in {} is only for premium members. Next update: {}".format(symbol,
-                self.ceil_dt(datetime.datetime.now(), datetime.timedelta(minutes=30))), flush=True)
+                                                                                                       self.ceil_dt(datetime.datetime.now(), datetime.timedelta(minutes=30))), flush=True)
 
     def run(self):
         # Main loop
+        print("BOT IS RUNNING... **(ignore the warning above)**", flush=True)
         self.order = BitmexOrder(self.symbols,
-                                 self.client, self.settings, self._settings_path)     
+                                 self.client, self.settings, self._settings_path)
         while True:
             signal = self.get_api_signal()
             if not signal:
@@ -189,13 +202,13 @@ class Lotus:
             else:
                 self.process_signals(signal, start=True)
                 break
-        print("BOT IS RUNNING... **(ignore the warning above)**", flush=True)
         while True:
             time.sleep(10)
             self.order.manage_entries(self.symbols)
             if datetime.datetime.utcnow().minute % 30 == 0:
                 second = datetime.datetime.utcnow().second
-                time.sleep(second + 19 - second + self.rand_sec(start=1, end=3))
+                time.sleep(second + 19 - second +
+                           self.rand_sec(start=1, end=3))
                 count_s_tries = 0
                 while True:
                     signal = self.get_api_signal()
@@ -213,5 +226,5 @@ class Lotus:
                         print('Signal is offline', flush=True)
                         break
                     time.sleep(self.rand_sec())
-                
+
                 time.sleep(40)
